@@ -288,21 +288,20 @@ impl QuicListener {
                             continue 'read;
                         }
                     };
-                    let mut write = None;
                     loop {
-                        match conn.send(&mut out) {
-                            Ok((len, _)) => write = Some(len),
+                        let (write, _) = match conn.send(&mut out) {
+                            Ok(v) => v,
                             Err(quiche::Error::Done) => {
                                 break;
                             }
                             Err(e) => return Err(io::Error::new(io::ErrorKind::Other, e)),
                         };
-                    }
-                    if let Err(e) = self.socket.send_to(&mut out[..write.unwrap()], &from) {
-                        if e.kind() == std::io::ErrorKind::WouldBlock {
-                            break;
+                        if let Err(e) = self.socket.send_to(&mut out[..write], &from) {
+                            if e.kind() == std::io::ErrorKind::WouldBlock {
+                                break;
+                            }
+                            panic!("send() failed: {:?}", e);
                         }
-                        panic!("send() failed: {:?}", e);
                     }
                 }
 
